@@ -186,7 +186,7 @@ class Dialcentral(object):
 		"""
 		# Barebones UI handlers
 		try:
-			import null_backend
+			from backends import null_backend
 			import null_views
 
 			self._phoneBackends = {self.NULL_BACKEND: null_backend.NullDialer()}
@@ -261,9 +261,10 @@ class Dialcentral(object):
 
 		# Setup costly backends
 		try:
-			import gv_backend
-			import file_backend
+			from backends import gv_backend
+			from backends import file_backend
 			import gv_views
+			from backends import merge_backend
 
 			try:
 				os.makedirs(constants._data_path_)
@@ -314,7 +315,7 @@ class Dialcentral(object):
 				self._phoneBackends[self.GV_BACKEND],
 				fileBackend,
 			]
-			mergedBook = gv_views.MergedAddressBook(addressBooks, gv_views.MergedAddressBook.advanced_lastname_sorter)
+			mergedBook = merge_backend.MergedAddressBook(addressBooks, merge_backend.MergedAddressBook.advanced_lastname_sorter)
 			self._contactsViews[self.GV_BACKEND].append(mergedBook)
 			self._contactsViews[self.GV_BACKEND].extend(addressBooks)
 			self._contactsViews[self.GV_BACKEND].open_addressbook(*self._contactsViews[self.GV_BACKEND].get_addressbooks().next()[0][0:2])
@@ -719,6 +720,11 @@ class Dialcentral(object):
 					self._window.unfullscreen()
 				else:
 					self._window.fullscreen()
+			elif event.keyval == ord("l") and event.get_state() & gtk.gdk.CONTROL_MASK:
+				with open(constants._user_logpath_, "r") as f:
+					logLines = f.xreadlines()
+					log = "".join(logLines)
+					self._clipboard.set_text(str(log))
 		except Exception, e:
 			self._errorDisplay.push_exception()
 
